@@ -1,6 +1,4 @@
-"""
-Testing functionality for geopandas objects.
-"""
+"""Testing functionality for geopandas objects."""
 
 import warnings
 
@@ -11,7 +9,7 @@ from geopandas.array import GeometryDtype
 
 
 def _isna(this):
-    """isna version that works for both scalars and (Geo)Series"""
+    """Version of isna that works for both scalars and (Geo)Series."""
     with warnings.catch_warnings():
         # GeoSeries.isna will raise a warning about no longer returning True
         # for empty geometries. This helper is used below always in combination
@@ -43,7 +41,6 @@ def _geom_equals_mask(this, that):
     Series
         boolean Series, True if geometries in left equal geometries in right
     """
-
     return (
         this.geom_equals(that)
         | (this.is_empty & that.is_empty)
@@ -66,7 +63,6 @@ def geom_equals(this, that):
     bool
         True if all geometries in left equal geometries in right
     """
-
     return _geom_equals_mask(this, that).all()
 
 
@@ -87,7 +83,6 @@ def _geom_almost_equals_mask(this, that):
     Series
         boolean Series, True if geometries in left almost equal geometries in right
     """
-
     return (
         this.geom_equals_exact(that, tolerance=0.5 * 10 ** (-6))
         | (this.is_empty & that.is_empty)
@@ -200,7 +195,7 @@ def assert_geoseries_equal(
 
 
 def _truncated_string(geom):
-    """Truncated WKT repr of geom"""
+    """Truncate WKT repr of geom."""
     s = str(geom)
     if len(s) > 100:
         return s[:100] + "..."
@@ -251,8 +246,7 @@ def assert_geodataframe_equal(
     check_crs=True,
     normalize=False,
 ):
-    """
-    Check that two GeoDataFrames are equal/
+    """Check that two GeoDataFrames are equal.
 
     Parameters
     ----------
